@@ -19,11 +19,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: codeset.h,v 1.1 2005/06/30 12:23:44 mschwerin Exp $
+ * $Id: codeset.h 1182 2006-09-22 07:53:33Z mschwerin $
  */
 
 #ifndef HAVE_CHARSET_H
 #define HAVE_CHARSET_H
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #ifdef HAVE_ICONV
 #include <iconv.h>
@@ -42,4 +45,7 @@ recode_t *recode_init (const char *src_encoding, const char *dst_encoding);
 void recode_done (recode_t * xr);
 char *recode (recode_t * xr, const char *src);
 
+#ifdef __cplusplus
+}
+#endif
 #endif
