@@ -19,12 +19,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: download.h,v 1.3 2006/01/18 15:31:17 mschwerin Exp $
+ * $Id: download.h 1182 2006-09-22 07:53:33Z mschwerin $
  *
  */
 
-#ifndef __DOWNLOAD_H__
-#define __DOWNLOAD_H__
+#ifndef HAVE_DOWNLOAD_H
+#define HAVE_DOWNLOAD_H
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 typedef struct {
     char *buf;
@@ -35,6 +38,12 @@ typedef struct {
 
 int network_download (const char *url, download_t * download);
 int is_downloadable (const char *url);
-char *download_to_cache (const char *url);
+char *download_to_cache (const char *url, const char *filename, int force_update);
 
+download_t * download_new (void);
+void download_free (download_t * download);
+
+#ifdef __cplusplus
+}
 #endif
+#endif /* HAVE_DOWNLOAD_H */
