@@ -18,13 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: playlist_menu.h,v 1.2 2005/12/12 15:04:32 mschwerin Exp $
+ * $Id: playlist_menu.h 1182 2006-09-22 07:53:33Z mschwerin $
  *
  */
 
 #ifndef HAVE_PLAYLIST_MENU_H
 #define HAVE_PLAYLIST_MENU_H
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 void show_playlist_menu_cb (void *oxine_p);
+void playlist_menu_free (void);
 
+#ifdef __cplusplus
+}
 #endif
+#endif /* HAVE_PLAYLIST_MENU_H */
