@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xmlparser.c,v 1.8 2005/12/03 17:32:47 mschwerin Exp $
+ * $Id: xmlparser.c 728 2006-02-09 16:28:00Z mschwerin $
  *
  */
 
@@ -227,7 +227,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             // lprintf ("info: node data : %s\n", current_node->data);
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                             break;
@@ -250,7 +250,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             // lprintf ("info: current node name \"%s\"\n", node_name);
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                             break;
@@ -320,7 +320,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             // lprintf ("info: current property name \"%s\"\n", property_name);
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                             break;
@@ -338,13 +338,13 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             if (strcmp (tok, root_name) == 0) {
                                 state = 4;
                             } else {
-                                error ("xml struct, tok=%s, waited_tok=%s.",
-                                       tok, root_name);
+                                error ("Found unexpected token '%s'. Expected token '%s' (state %d).",
+                                       tok, root_name, state);
                                 return -1;
                             }
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                             break;
@@ -358,7 +358,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             return 0;
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                             break;
@@ -395,7 +395,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             state = 2;
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                     }
@@ -426,7 +426,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                             state = 2;
                             break;
                         default:
-                            error ("unexpected token \"%s\", state %d.", tok,
+                            error ("Found unexpected token '%s' (state %d).", tok,
                                    state);
                             return -1;
                     }
@@ -468,9 +468,8 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
                     }
                     break;
 
-
                 default:
-                    error ("unknown parser state, state=%d.", state);
+                    error ("We are in an unknown parser state (state=%d).", state);
                     return -1;
             }
         }
@@ -479,7 +478,7 @@ xml_parser_get_node (xml_node_t * current_node, char *root_name, int rec)
         return -1;
     } else {
         /* max recursion */
-        error ("max recursion");
+        error ("The maximum recursion depth (%d) has been reached.", MAX_RECURSION);
         return -1;
     }
 }
